@@ -519,6 +519,8 @@ class VM(_ValueBase):
             byref(self._vm)))
 
     def close(self):
+        for name in self._ff_registry.keys():
+            self.delete_foreign_function(name)
         res = handle_return_value(unqlite_vm_release(self._vm))
         self._vm = None
         return res
